==> speech-analytic-testing_2.3.1_database.tar.gz: database/mssql/procedures/GetBatchScheduleExecutionsByCriteria.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetBatchScheduleExecutionsByCriteria] (
	@VCC VARCHAR(50) = NULL, 
	@SearchCriteria VARCHAR(50) = NULL,
	@SearchExpression VARCHAR(500) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	DECLARE @SQL VARCHAR(MAX) = ''
	-- DECLARAMOS CADENAS PARA EL QUERY FINAL
	DECLARE @SQL_SELECT VARCHAR(MAX) = ''
	DECLARE @SQL_FROM VARCHAR(MAX) = ''
	DECLARE @SQL_EXTRA VARCHAR(MAX) = ''
    DECLARE @FILTERS_OPTIONAL_PART VARCHAR(MAX) = ''
    DECLARE @FILTERS_EXCLUDING_PART VARCHAR(MAX) = ''
    DECLARE @FILTERS_FIXED_PART     VARCHAR(MAX) = ''

	SET @SQL_SELECT = '
		SELECT BSE.[VCC]									''vcc'',
				BSE.[Id]									''id'', 
				BSE.[BatchScheduleId]						''batchScheduleId'', 
				BSE.[BatchId]								''batchId'', 
				BSE.[ExecutionDate]							''executionDate'', 
				BSE.[Order]									''order'', 
				BSE.[Status]								''status'', 
				BSE.[CreatedDate]							''createdDate'',
				BSE.[CreatedByUserId]						''createdByUserId'',
				BSE.[LastModifiedDate]						''lastModifiedDate'',
				BSE.[LastModifiedByUserId]					''lastModifiedByUserId'',
				RN = ROW_NUMBER() OVER(PARTITION BY BSE.[VCC],
													BSE.[BatchScheduleId]
										ORDER BY BSE.[ExecutionDate] DESC) '

	-- ARMAMOS LA PARTE DE TABLAS 
	SET @SQL_FROM += '
			FROM [dbo].[BatchScheduleExecution] BSE (NOLOCK) '

	-- ARMAMOS LA PARTE BASE DE FILTROS
	SET @FILTERS_FIXED_PART = '
			WHERE BSE.[Id] IS NOT NULL '

	-- 
	IF @VCC IS NOT NULL
		SET @FILTERS_OPTIONAL_PART += '
				AND BSE.[VCC] = ''' + @VCC + ''' '

	/* DEPRECATED
	-- CUANDO SE HACE BUSQUEDA POR ULTIMA EJECUCIONES
	IF @SearchCriteria = 'ALREADY_EXECUTED_BY_BS_ID'
		SET @FILTERS_OPTIONAL_PART += '
				AND BSE.[BatchScheduleId] = ''' + @SearchExpression + ''' 
				AND BSE.[Status] <> ''PENDING'' '
	*/
	
	-- CUANDO SE HACE BUSQUEDA POR NO EJECUTADAS
	IF @SearchCriteria = 'NO_EXECUTED_BY_SCHEDULE_ID'
	SET @FILTERS_OPTIONAL_PART += '
				AND BSE.[BatchScheduleId] IN (SELECT Value FROM [dbo].[split](''' + @SearchExpression + ''','','')) 
				AND BSE.[Status] IN (''PENDING'', ''REGISTERED_ON_REDIS'') '

	-- CUANDO SE HACE BUSQUEDA MULTIPLE POR IDS
	IF @SearchCriteria = 'NOT_CREATED_BY_BS_ID'
		SET @FILTERS_OPTIONAL_PART += '
				AND BSE.[BatchScheduleId] IN (SELECT Value FROM [dbo].[split](''' + @SearchExpression + ''','',''))
				AND BSE.[BatchId] IS NULL 
				AND BSE.[Status] NOT LIKE ''CANCELLED_%'' '

	-- CUANDO SE HACE BUSQUEDA POR ULTIMA EJECUCIONES
	IF @SearchCriteria = 'LAST_CREATED_EXECUTIONS'
	SET @FILTERS_OPTIONAL_PART += '
				AND BSE.[BatchScheduleId] IN (SELECT Value FROM [dbo].[split](''' + @SearchExpression + ''','','')) '
	
	-- EL FILTRO POR DEFECTO
	IF @SQL_EXTRA IS NULL OR @SQL_EXTRA  = ''
		SET @SQL_EXTRA += '
			ORDER BY BSE.[ExecutionDate] ASC, BSE.[BatchScheduleId] '

	
	
	-- CUANDO SE HACE BUSQUEDA POR ULTIMA EJECUCIONES
	IF @SearchCriteria = 'LAST_CREATED_EXECUTIONS'
	BEGIN
		-- UNIMOS LAS PARTES DEL QUERY
		SET @SQL_SELECT += @SQL_FROM + @FILTERS_FIXED_PART + @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART
		
		--
		SET @SQL = ';WITH CTE AS (' + @SQL_SELECT + ')'

	
		SET @SQL += 'SELECT * FROM CTE BSE WHERE RN = 1 ORDER BY BSE.[ExecutionDate] DESC, BSE.[BatchScheduleId] '
	END
	ELSE
	BEGIN
		-- UNIMOS LAS PARTES DEL QUERY
		SET @SQL_SELECT += @SQL_FROM + @FILTERS_FIXED_PART + @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART + @SQL_EXTRA
		SET @SQL += @SQL_SELECT
	END

	-- EJECUTAMOS LA QUERY
	EXEC (@SQL)

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_2.4.1_database.tar.gz: database/mssql/procedures/GetBatchScheduleExecutionsByCriteria.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetBatchScheduleExecutionsByCriteria] (
	@VCC VARCHAR(50) = NULL, 
	@SearchCriteria VARCHAR(50) = NULL,
	@SearchExpression VARCHAR(500) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	DECLARE @SQL VARCHAR(MAX) = ''
	-- DECLARAMOS CADENAS PARA EL QUERY FINAL
	DECLARE @SQL_SELECT VARCHAR(MAX) = ''
	DECLARE @SQL_FROM VARCHAR(MAX) = ''
	DECLARE @SQL_EXTRA VARCHAR(MAX) = ''
    DECLARE @FILTERS_OPTIONAL_PART VARCHAR(MAX) = ''
    DECLARE @FILTERS_EXCLUDING_PART VARCHAR(MAX) = ''
    DECLARE @FILTERS_FIXED_PART     VARCHAR(MAX) = ''

	SET @SQL_SELECT = '
		SELECT BSE.[VCC]									''vcc'',
				BSE.[Id]									''id'', 
				BSE.[BatchScheduleId]						''batchScheduleId'', 
				BSE.[BatchId]								''batchId'', 
				BSE.[ExecutionDate]							''executionDate'', 
				BS.[ExecutionDelay]							''executionDelay'',
				BSE.[Order]									''order'', 
				BSE.[Status]								''status'', 
				BSE.[CreatedDate]							''createdDate'',
				BSE.[CreatedByUserId]						''createdByUserId'',
				BSE.[LastModifiedDate]						''lastModifiedDate'',
				BSE.[LastModifiedByUserId]					''lastModifiedByUserId'',
				RN = ROW_NUMBER() OVER(PARTITION BY BSE.[VCC],
													BSE.[BatchScheduleId]
										ORDER BY BSE.[ExecutionDate] DESC) '

	-- ARMAMOS LA PARTE DE TABLAS 
	SET @SQL_FROM += '
			FROM [dbo].[BatchScheduleExecution] BSE (NOLOCK)
			INNER JOIN [dbo].[BatchSchedule] BS (NOLOCK)
				ON BS.[VCC] = BSE.[VCC]
					AND BS.[Id] = BSE.[BatchScheduleId] '

	-- ARMAMOS LA PARTE BASE DE FILTROS
	SET @FILTERS_FIXED_PART = '
			WHERE BSE.[Id] IS NOT NULL '

	-- 
	IF @VCC IS NOT NULL
		SET @FILTERS_OPTIONAL_PART += '
				AND BSE.[VCC] = ''' + @VCC + ''' '

	/* DEPRECATED
	-- CUANDO SE HACE BUSQUEDA POR ULTIMA EJECUCIONES
	IF @SearchCriteria = 'ALREADY_EXECUTED_BY_BS_ID'
		SET @FILTERS_OPTIONAL_PART += '
				AND BSE.[BatchScheduleId] = ''' + @SearchExpression + ''' 
				AND BSE.[Status] <> ''PENDING'' '
	*/
	
	-- CUANDO SE HACE BUSQUEDA POR NO EJECUTADAS
	IF @SearchCriteria = 'NO_EXECUTED_BY_SCHEDULE_ID'
	SET @FILTERS_OPTIONAL_PART += '
				AND BSE.[BatchScheduleId] IN (SELECT Value FROM [dbo].[split](''' + @SearchExpression + ''','','')) 
				AND BSE.[Status] IN (''PENDING'', ''REGISTERED_ON_REDIS'') '

	-- CUANDO SE HACE BUSQUEDA MULTIPLE POR IDS
	IF @SearchCriteria = 'NOT_CREATED_BY_BS_ID'
		SET @FILTERS_OPTIONAL_PART += '
				AND BSE.[BatchScheduleId] IN (SELECT Value FROM [dbo].[split](''' + @SearchExpression + ''','',''))
				AND BSE.[BatchId] IS NULL 
				AND BSE.[Status] NOT LIKE ''CANCELLED_%'' '

	-- CUANDO SE HACE BUSQUEDA POR ULTIMA EJECUCIONES
	IF @SearchCriteria = 'LAST_CREATED_EXECUTIONS'
	SET @FILTERS_OPTIONAL_PART += '
				AND BSE.[BatchScheduleId] IN (SELECT Value FROM [dbo].[split](''' + @SearchExpression + ''','','')) '
	
	-- EL FILTRO POR DEFECTO
	IF @SQL_EXTRA IS NULL OR @SQL_EXTRA  = ''
		SET @SQL_EXTRA += '
			ORDER BY BSE.[ExecutionDate] ASC, BSE.[BatchScheduleId] '

	
	
	-- CUANDO SE HACE BUSQUEDA POR ULTIMA EJECUCIONES
	IF @SearchCriteria = 'LAST_CREATED_EXECUTIONS'
	BEGIN
		-- UNIMOS LAS PARTES DEL QUERY
		SET @SQL_SELECT += @SQL_FROM + @FILTERS_FIXED_PART + @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART
		
		--
		SET @SQL = ';WITH CTE AS (' + @SQL_SELECT + ')'

	
		SET @SQL += 'SELECT * FROM CTE BSE WHERE RN = 1 ORDER BY BSE.[ExecutionDate] DESC, BSE.[BatchScheduleId] '
	END
	ELSE
	BEGIN
		-- UNIMOS LAS PARTES DEL QUERY
		SET @SQL_SELECT += @SQL_FROM + @FILTERS_FIXED_PART + @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART + @SQL_EXTRA
		SET @SQL += @SQL_SELECT
	END

	-- EJECUTAMOS LA QUERY
	EXEC (@SQL)

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
